@@ -21,7 +21,7 @@ from calculate.lib.datavars import VariableError,DataVarsError
 from calculate.core.server.func import WsdlBase
 from calculate.install.install import InstallError
 from calculate.update.update import Update, UpdateError
-from calculate.lib.utils.portage import GitError
+from calculate.lib.utils.git import GitError
 from utils.cl_update import ClUpdateAction
 from utils.cl_update_profile import ClUpdateProfileAction
 from utils.cl_setup_update import ClSetupUpdateAction
